#
# spec file for package clustduct
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


#
%define tftpdir /srv/tftpboot

%bcond_with pdfdoc

Name:           clustduct
Version:        0.0.6
Release:        2.10
Summary:        Framework which connects a genders database to dnsmasq
License:        BSD-3-Clause
Group:          System/Management
Source0:        https://github.com/mslacken/clustduct/archive/v%{version}.tar.gz#/clustduct-%{version}.tar.gz
Source1:        clustduct-rpmlintrc
URL:            https://github.com/mslacken/clustduct   
BuildRequires:  autoconf-archive
BuildRequires:  automake
BuildRequires:  coreutils
BuildRequires:  dnsmasq
BuildRequires:  lua
BuildRequires:  lua-genders
%if %{with pdfdoc}
BuildRequires:  pandoc
BuildRequires:  texlive-latex
%endif
Requires:       bc
Requires:       dnsmasq
Requires:       dolly
Requires:       genders
Requires:       lua-genders
%ifarch x86_64
Requires:       grub2-x86_64-efi
Requires:       shim
Requires:       syslinux
BuildRequires:  grub2-x86_64-efi
BuildRequires:  shim
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Conflicts:      apparmor
Recommends:     python3-kiwi
Recommends:     git

%description
This framework feeds dnsmasq with the node information of a genders
database. It can also create a PXE boot file structure with the possiblity to
update node MAC addresses in the genders database. In addition, boot images
can be managed in the PXE environment.

%prep
# macro for removing nested directories
%define sanitize_dir() _uglydir=$(ls -d *); shopt -s dotglob;mv $_uglydir/* .; rmdir $_uglydir
%setup -q -c -n %{name}-%{version}
%sanitize_dir  %{name}-%{version}

%build
%if %{with pdfdoc}
for file in *.md ; do 
	pandoc -o ${file%%md}pdf $file
done
%endif

autoreconf -i
%configure

%install
%make_install

%files
%defattr(-,root,root)
%if %{with pdfdoc}
%doc *.pdf
%endif
%license COPYING

%{_sbindir}/clustduct.lua
%{_sbindir}/write_bf.lua
%{_sbindir}/prepare_tftp.sh
%config %{_sysconfdir}/clustduct.d/
%config %{_sysconfdir}/clustduct.conf
%{_datadir}/doc/%{name}
%{_libdir}/lua

%changelog
* Tue Feb 16 2021 Christian Goll <cgoll@suse.com>
- updated to v0.0.6 which support lua54 and Leap/SLE15.3 and
  support dolly as distribution method
* Tue Mar 17 2020 Christian Goll <cgoll@suse.com>
- removed last remaing %%is_opensuse (jsc#SLE-11639)
* Thu Mar  5 2020 Christian Goll <cgoll@suse.com>
- removed is_opensuse form the pdf creation, as pdfs are not
  built right now
* Mon Dec  2 2019 Christian Goll <cgoll@suse.com>
- updated to vers v0.0.5 to fix open issues of (bsc#1138326)
- using _service file for github source
* Fri Jul  5 2019 Christian Goll <cgoll@suse.com>
- updated to vers v0.0.4 which includes several fixes
  * description
  * option handeling
  * renamed kiwi description
  Bugs are listed in (bsc#1138326) and (bsc#1138296)
* Fri May  3 2019 Christian Goll <cgoll@suse.com>
- updated to v0.0.2 to use the right product (bsc#1131150)
* Thu May  2 2019 Christian Goll <cgoll@suse.com>
- adds the valid SLE15SP1 descriptions (bsc#1131150)
* Mon Apr  1 2019 Christian Goll <cgoll@suse.com>
- Updated to v0.0.1_alpha7 which adds close to every lua file
  operation (BSC#1131151)
  * added SLES kiwi descriptions for SLES builds
* Fri Feb  8 2019 cgoll@suse.com
- Updated to alpha5 which fixes linebreak in perpare_tftp.sh
  (BSC#1124812)
* Tue Dec  4 2018 cgoll@suse.com
- added COPYING as license and simplified spec file
* Thu Nov 29 2018 cgoll@suse.com
- Updated to 0.0.1_alpha4 which does not install files to /srv any
  more and do not require specific lua and syslinux for build
* Wed Nov  7 2018 cgoll@suse.com
- Updated to 0.0.1_alpha3 with a script for preparing the
  tftp directories
  * removed post sections which prepared the tftp directory
* Mon Nov  5 2018 Jan Engelhardt <jengelh@inai.de>
- Fix some orthography points in the description.
- Wrap entire %%post in ifarch x86_64.
* Thu Oct 25 2018 cgoll@suse.com
- Updated to 0.0.1_alpha2 which now has as kiwi example file
* Fri Oct 19 2018 cgoll@suse.com
- Updated to version 0.0.1_alpha with following features
  * lua based
  * BSD-3 license
  * autobuild based
* Thu Aug  2 2018 cgoll@suse.com
- First commit, which installs clustduct.sh to /usr/sbin
  (FATE#326456).
